@@ -1,7 +1,7 @@
 # -*- coding: utf-8 -*-
 # Orca
 #
-# Copyright 2004-2006 Sun Microsystems Inc.
+# Copyright 2004-2008 Sun Microsystems Inc.
 #
 # This library is free software; you can redistribute it and/or
 # modify it under the terms of the GNU Library General Public
@@ -15,16 +15,16 @@
 #
 # You should have received a copy of the GNU Library General Public
 # License along with this library; if not, write to the
-# Free Software Foundation, Inc., 59 Temple Place - Suite 330,
-# Boston, MA 02111-1307, USA.
+# Free Software Foundation, Inc., Franklin Street, Fifth Floor,
+# Boston MA  02110-1301 USA.
 
 """Provides getCharacterName that maps punctuation marks and other
 individual characters into localized words."""
 
-__id__        = "$Id: chnames.py 3422 2008-01-02 17:19:55Z richb $"
-__version__   = "$Revision: 3422 $"
-__date__      = "$Date: 2008-01-02 12:19:55 -0500 (Wed, 02 Jan 2008) $"
-__copyright__ = "Copyright (c) 2005-2006 Sun Microsystems Inc."
+__id__        = "$Id$"
+__version__   = "$Revision$"
+__date__      = "$Date$"
+__copyright__ = "Copyright (c) 2005-2008 Sun Microsystems Inc."
 __license__   = "LGPL"
 
 from orca_i18n import _ # for gettext support
@@ -276,7 +276,7 @@ chnames[u'\u00b9'] = _("superscript 1")
 
 # Translators: this is the spoken word for the character 'º' (U+00ba)
 #
-chnames[u'\u00ba'] = _("degrees")
+chnames[u'\u00ba'] = _("ordinal")
 
 # Translators: this is the spoken word for the character '»' (U+00bb)
 #
@@ -576,6 +576,10 @@ chnames[u'\u2018'] = _("left single quote")
 #
 chnames[u'\u2019'] = _("right single quote")
 
+# Translators: this is the spoken word for the character '‚' (U+201a)
+#
+chnames[u'\u201a'] = _("single low quote")
+
 # Translators: this is the spoken word for the character '“' (U+201c)
 #
 chnames[u'\u201c'] = _("left double quote")
@@ -584,6 +588,10 @@ chnames[u'\u201c'] = _("left double quote")
 #
 chnames[u'\u201d'] = _("right double quote")
 
+# Translators: this is the spoken word for the character '„' (U+201e)
+#
+chnames[u'\u201e'] = _("double low quote")
+
 # Translators: this is the spoken word for the character '†' (U+2020)
 #
 chnames[u'\u2020'] = _("dagger")
@@ -707,6 +715,12 @@ chnames[u'\u2717'] = _("x-shaped bullet")
 #
 chnames[u'\u2974'] = _("right-pointing arrow")
 
+# WDW - we reuse 'right-pointing arrow' here (see 2974 entry above) to
+# avoid a string change for 2.26.3.  In 2.27.x, this is now 'right
+# arrow'.
+#
+chnames[u'\u2192'] = chnames[u'\u2974']
+
 # Translators: this is the spoken word for the character '➢' (U+27a2)
 # This symbol is included here because it can be used as a bullet in an 
 # OOo list. The goal is to inform the user of the appearance of the bullet 
