@@ -26,6 +26,8 @@ __date__      = "$Date$"
 __copyright__ = "Copyright (c) 2006-2008 Sun Microsystems Inc."
 __license__   = "LGPL"
 
+import chnames
+
 def getPronunciation(word, pronunciations=None):
     """Given a word, return a string that represents what this word
     sounds like.
@@ -49,6 +51,11 @@ def getPronunciation(word, pronunciations=None):
         else:
             return pronunciation_dict[lowerWord][1]
     except:
+        # If you want a character name to be spoken, treat it as a
+        # punctuation character at LEVEL_NONE in puncutation_settings.py.
+        # See, for example, the left_arrow and right_arrow characters.
+        #
+        #return chnames.getCharacterName(word)
         return word
 
 def setPronunciation(word, replacementString, pronunciations=None):
