@@ -20,9 +20,9 @@
 """ Custom script for Thunderbird 3.
 """
 
-__id__        = "$Id: script.py 4337 2008-11-17 22:01:23Z joanied $"
-__version__   = "$Revision: 4337 $"
-__date__      = "$Date: 2008-11-17 17:01:23 -0500 (Mon, 17 Nov 2008) $"
+__id__        = "$Id$"
+__version__   = "$Revision$"
+__date__      = "$Date$"
 __copyright__ = "Copyright (c) 2005-2008 Sun Microsystems Inc."
 __license__   = "LGPL"
 
@@ -238,7 +238,16 @@ class Script(Gecko.Script):
             row = table.getRowAtIndex(self.getCellIndex(obj))
             for i in range(0, table.nColumns):
                 acc = table.getAccessibleAt(row, i)
-                if acc.name:                
+                if acc.name:
+                    # For some reason orca.py's check to see if the
+                    # object we're setting the locusOfFocus to is the
+                    # same as the current locusOfFocus is returning
+                    # True when it's not actually True. Therefore,
+                    # we'll set the current locusOfFocus to None as
+                    # a precaution.
+                    #
+                    if event.type.startswith("focus:"):
+                        orca_state.locusOfFocus = None
                     orca.setLocusOfFocus(event, acc)
                     consume = True
                     break
@@ -345,12 +354,10 @@ class Script(Gecko.Script):
         # number as the previously deleted message).
         # See bug #536451 for more details.
         #
-        rolesList = [pyatspi.ROLE_TABLE_CELL, \
-                     pyatspi.ROLE_TREE_TABLE, \
-                     pyatspi.ROLE_SCROLL_PANE, \
-                     pyatspi.ROLE_SCROLL_PANE, \
-                     pyatspi.ROLE_FRAME, \
-                     pyatspi.ROLE_APPLICATION]
+        rolesList = [pyatspi.ROLE_TABLE_CELL,
+                     pyatspi.ROLE_TREE_TABLE,
+                     pyatspi.ROLE_SCROLL_PANE,
+                     pyatspi.ROLE_SCROLL_PANE]
         if self.isDesiredFocusedItem(event.source, rolesList):
             if isinstance(orca_state.lastInputEvent, input_event.KeyboardEvent):
                 string = orca_state.lastNonModifierKeyEvent.event_string
@@ -576,6 +583,9 @@ class Script(Gecko.Script):
         Overridden here because multiple open messages are not arranged
         in tabs like they are in Firefox."""
 
+        if self.inFindToolbar():
+            return Gecko.Script.getDocumentFrame(self)
+
         obj = orca_state.locusOfFocus
         while obj:
             role = obj.getRole()
@@ -585,3 +595,13 @@ class Script(Gecko.Script):
                 obj = obj.parent
 
         return None
+
+    def toggleFlatReviewMode(self, inputEvent=None):
+        """Toggles between flat review mode and focus tracking mode."""
+
+        # If we're leaving flat review dump the cache. See bug 568658.
+        #
+        if self.flatReviewContext:
+            pyatspi.clearCache()
+
+        return default.Script.toggleFlatReviewMode(self, inputEvent)
