@@ -19,9 +19,9 @@
 
 """Custom script for gedit."""
 
-__id__        = "$Id: script.py 3882 2008-05-07 18:22:10Z richb $"
-__version__   = "$Revision: 3882 $"
-__date__      = "$Date: 2008-05-07 14:22:10 -0400 (Wed, 07 May 2008) $"
+__id__        = "$Id$"
+__version__   = "$Revision$"
+__date__      = "$Date$"
 __copyright__ = "Copyright (c) 2005-2008 Sun Microsystems Inc."
 __license__   = "LGPL"
 
@@ -30,6 +30,7 @@ import pyatspi
 import orca.braille as braille
 import orca.debug as debug
 import orca.default as default
+import orca.input_event as input_event
 import orca.orca as orca
 import orca.orca_state as orca_state
 import orca.settings as settings
@@ -38,8 +39,6 @@ import orca.speechserver as speechserver
 
 from orca.orca_i18n import _
 
-from speech_generator import SpeechGenerator
-
 class Script(default.Script):
 
     def __init__(self, app):
@@ -68,11 +67,6 @@ class Script(default.Script):
         self.lastBadWord = ''
         self.lastEventType = ''
 
-    def getSpeechGenerator(self):
-        """Returns the speech generator for this script.
-        """
-        return SpeechGenerator(self)
-
     def getListeners(self):
         """Sets up the AT-SPI event listeners for this script.
         """
@@ -298,6 +292,9 @@ class Script(default.Script):
         """
 
         obj = orca_state.locusOfFocus
+        if not obj:
+            return False
+
         rolesList1 = [pyatspi.ROLE_PUSH_BUTTON,
                       pyatspi.ROLE_FILLER,
                       pyatspi.ROLE_FILLER,
@@ -502,6 +499,7 @@ class Script(default.Script):
         #
         if event.source.getRole() == pyatspi.ROLE_STATUS_BAR \
            and self.isFocusOnFindDialog() \
+           and orca_state.lastNonModifierKeyEvent \
            and orca_state.lastNonModifierKeyEvent.event_string == "Return" \
            and event.source.name == _("Phrase not found"):
             debug.println(self.debugLevel,
@@ -557,6 +555,7 @@ class Script(default.Script):
         # we've just found.
         #
         if self.isFocusOnFindDialog() \
+           and orca_state.lastNonModifierKeyEvent \
            and orca_state.lastNonModifierKeyEvent.event_string == "Return":
             debug.println(self.debugLevel, "gedit.onCaretMoved - find dialog.")
             allComboBoxes = \
@@ -573,6 +572,16 @@ class Script(default.Script):
                 utterances = self.speechGenerator.getSpeech(event.source, True)
                 speech.speakUtterances(utterances)
 
+        # If Ctrl+G was used to repeat a find command, speak the line that
+        # the caret moved to.
+        #
+        if orca_state.lastInputEvent \
+           and isinstance(orca_state.lastInputEvent, input_event.KeyboardEvent)\
+           and orca_state.lastInputEvent.event_string == 'G' \
+           and orca_state.lastInputEvent.modifiers \
+               & (1 << pyatspi.MODIFIER_CONTROL):
+            self.sayLine(event.source)
+
         # For everything else, pass the caret moved event onto the parent
         # class to be handled in the default way.
 
